# Tensaero
A portmanteau of tensor + aerodynamics, Tensaero is a 3DOF modeling & 
simulation software suite in the early stages of development.

# License

This project - except for the IERS and WGS84 data files - is covered under the 
Mozilla Public License Version 2.0 (MPL2). See the LICENSE.txt file for more
information.
